Unnamed repository; edit this file 'description' to name the repository.
Add .svn as workspace root marker (#11429)
* add .svn as workspace-root marker * cargo fmt
yehor 2024-08-09
parent 518425e · commit 9678c3f
-rw-r--r--helix-loader/src/lib.rs7
1 files changed, 5 insertions, 2 deletions
diff --git a/helix-loader/src/lib.rs b/helix-loader/src/lib.rs
index badb9bd6..f36c76c4 100644
--- a/helix-loader/src/lib.rs
+++ b/helix-loader/src/lib.rs
@@ -225,13 +225,16 @@ pub fn merge_toml_values(left: toml::Value, right: toml::Value, merge_depth: usi
/// Used as a ceiling dir for LSP root resolution, the filepicker and potentially as a future filewatching root
///
/// This function starts searching the FS upward from the CWD
/// and returns the first directory that contains either `.git` or `.helix`.
/// If no workspace was found returns (CWD, true).
/// Otherwise (workspace, false) is returned
pub fn find_workspace() -> (PathBuf, bool) {
let current_dir = current_working_dir();
for ancestor in current_dir.ancestors() {
- if ancestor.join(".git").exists() || ancestor.join(".helix").exists() {
+ if ancestor.join(".git").exists()
+ || ancestor.join(".svn").exists()
+ || ancestor.join(".helix").exists()
+ {
return (ancestor.to_owned(), false);
}
}
@@ -225,13 +225,16 @@ pub fn merge_toml_values(left: toml::Value, right: toml::Value, merge_depth: usi
///
/// This function starts searching the FS upward from the CWD
-/// and returns the first directory that contains either `.git` or `.helix`.
+/// and returns the first directory that contains either `.git`, `.svn` or `.helix`.
/// If no workspace was found returns (CWD, true).
/// Otherwise (workspace, false) is returned